@@ -1,5 +1,5 @@
 package Number::Tolerant::Union;
-our $VERSION = "1.29_01";
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.1 $ =~ /(\d+)/g;
 
 use strict;
 use warnings;
@@ -8,12 +8,6 @@ use warnings;
 
 Number::Tolerant::Union -- unions of tolerance ranges
 
-=head1 VERSION
-
-version 1.29_01
-
- $Id: Union.pm,v 1.8 2004/08/20 18:03:24 rjbs Exp $
-
 =head1 SYNOPSIS
 
  use Number::Tolerant;
@@ -39,7 +33,7 @@ tolerance will function on a union of tolerances, as listed below.
 
 =head1 METHODS
 
-=head2 C<< Number::Tolerant::Union->new( @options ) >>
+=head2 Instantiation
 
 There is a C<new> method on the Number::Tolerant::Union class, but unions are
 meant to be created with the C<|> operator on a Number::Tolerant tolerance.
@@ -57,12 +51,6 @@ sub new {
 	bless { options => [ @_ ] } => $class;
 }
 
-=head2 options
-
-This method will return a list of all the acceptable options for the union.
-
-=cut
-
 sub options {
 	my $self = shift;
 	return @{$self->{options}};
@@ -95,14 +83,7 @@ A number is less than a union if it is less than all its options.
 
 =item union intersection
 
-An intersection (C<&>) with a union is commutted across all options.  In other
-words:
-
- (a | b | c) & d  ==yields==> ((a & d) | (b & d) | (c & d))
-
-Options that have no intersection with the new element are dropped.  The
-intersection of a constant number and a union yields that number, if the number
-was in the union's ranges and otherwise yields nothing.
+There is no C<&> operator overloading for unions... yet.
 
 =cut
 
@@ -121,26 +102,14 @@ use overload
 			if ($_[2]) { for ($_[0]->options) { return 0 unless $_[1] < $_ } return 1 }
 			else       { for ($_[0]->options) { return 0 unless $_[1] > $_ } return 1 }
 		},
-	'<=>' =>
-		sub {
-			if ($_[2]) { $_[0] < $_[1] ? 1 : $_[0] > $_[1] ? -1 : 0 }
-			else       { $_[0] > $_[1] ? 1 : $_[0] < $_[1] ? -1 : 0 }
-		},
-	'|' => sub { __PACKAGE__->new($_[0]->options,$_[1]); },
-	'&' => sub {
-		UNIVERSAL::isa($_[1],'Number::Tolerant')
-			? __PACKAGE__->new(map { $_ & $_[1] } $_[0]->options )
-			: $_[1] == $_[0]
-				? $_[1]
-				: ();
-		},
+	'<=>' => sub { undef },
 	fallback => 1;
 
 =back
 
 =head1 TODO
 
-Who knows.  Collapsing overlapping options, probably.
+Who knows.  Intersection commution, probably.
 
 =head1 AUTHOR
 
